Learn R Programming

DTSg (version 0.6.0)

cols.DTSg: Get Column Names

Description

Queries all column names of a DTSg object, those of certain classes and/or those matching a certain pattern only.

Usage

# S3 method for DTSg
cols(x, class = NULL, pattern = NULL, ...)

Arguments

x

A DTSg object (S3 method only).

class

An optional character vector matched to the most specific class (first element) of each column's class vector.

pattern

An optional character string passed on to the pattern argument of grep.

Further arguments passed on to grep. The value argument is rejected.

Value

Returns a character vector.

See Also

DTSg, class, grep

Examples

Run this code
# NOT RUN {
# new DTSg object
x <- DTSg$new(values = flow)

# get names of numeric columns
## R6 method
x$cols(class = "numeric")

## S3 method
cols(x = x, class = "numeric")

# }

Run the code above in your browser using DataLab