Learn R Programming

DTSg (version 0.6.0)

getCol.DTSg: Get Column Vector

Description

Queries the values of a column of a DTSg object. The extract operator ([) acts as a shortcut for getCol.

Usage

# S3 method for DTSg
getCol(x, col = self$cols(class = "numeric")[1L], ...)

# S3 method for DTSg [(x, ...)

Arguments

x

A DTSg object (getCol S3 method only).

col

A character string specifying a column name.

Arguments passed on to getCol (only used by the extract operator).

Value

Returns a vector or a list in case of a list column.

See Also

DTSg, cols, list

Examples

Run this code
# NOT RUN {
# new DTSg object
x <- DTSg$new(values = flow)

# get values of "flow" column
## R6 methods
x$getCol(col = "flow")
x$`[`("flow")

## S3 methods
getCol(x = x, col = "flow")
x["flow"]

# }

Run the code above in your browser using DataLab