powered by
Calculates summary statistics of selected columns of a DTSg object.
DTSg
# S3 method for DTSg summary(object, cols = self$cols(), ...)
A DTSg object (S3 method only).
A character vector specifying the columns whose values shall be summarised.
Further arguments passed on to summary.data.frame.
summary.data.frame
Returns a table.
table
DTSg, cols, summary.data.frame, table
cols
# NOT RUN { # new DTSg object x <- DTSg$new(values = flow) # calculate summary statistics ## R6 method x$summary() ## S3 method summary(object = x) # }
Run the code above in your browser using DataLab