Learn R Programming

DTSg (version 0.2.0)

S3WrapperGenerator: S3 Wrapper Method Generator

Description

Generates S3 wrapper methods for public methods of R6ClassGenerators, but can also be used to generate “plain” function wrappers.

Usage

S3WrapperGenerator(R6Method, self = "x", dots = TRUE)

Arguments

R6Method

An expression with a public method of an R6ClassGenerator.

self

A character string specifying the name of the parameter which will take the R6 object.

dots

A logical specifying if a parameter shall be added as last parameter in case none already exists. This might be required for S3 generic/method consistency.

Value

Returns a function with the required parameters which captures its own call, reshapes it to the corresponding R6 method call and evaluates it.

See Also

S3Methods, R6Class, expression

Examples

Run this code
# NOT RUN {
# generate S3 wrapper method for alter of DTSg
alter.DTSg <- S3WrapperGenerator(
  R6Method = expression(DTSg$public_methods$alter)
)

# }

Run the code above in your browser using DataLab