An expression with a public method of an
R6ClassGenerator.
self
A character string specifying the name of the parameter which
will take the R6 object.
dots
A logical specifying if a … parameter shall be added
as last parameter in case none already exists. This might be required for S3
generic/method consistency.
Value
Returns a function with the required parameters which captures its
own call, reshapes it to the corresponding R6 method call and evaluates it.